{
  description = "A basic Rust devshell for NixOS users developing gtk/libadwaita apps";

  inputs = {
    nixpkgs.url      = "github:NixOS/nixpkgs/nixos-unstable";
    rust-overlay.url = "github:oxalica/rust-overlay";
    flake-utils.url  = "github:numtide/flake-utils";
  };

  outputs = { self, nixpkgs, rust-overlay, flake-utils, ... }:
    flake-utils.lib.eachDefaultSystem (system:
      let
        overlays = [ (import rust-overlay) ];
        pkgs = import nixpkgs {
          inherit system overlays ;
        };

      in
      with pkgs;
      {
        devShells.default = mkShell {
          nativeBuildInputs = [
            # we need this to properly configure dependencies like openssl
            pkg-config
          ];
          
          buildInputs = [
            openssl
            pkg-config
            cacert
            cargo-make
            cargo-cross
            gtk4
            wrapGAppsHook4 # this is needed for relm4-icons to properly load after gtk::init()
            libadwaita
            gobject-introspection
            lldb
            (rust-bin.selectLatestNightlyWith( toolchain: toolchain.default.override {
              extensions= [ "rust-src" "rust-analyzer" ];
              targets = [ "wasm32-unknown-unknown" "aarch64-unknown-linux-gnu" ];
            }))
            perl
          ];

          packages = [
            bacon
          ];

          shellHook = ''
          '';

          PKG_CONFIG_PATH = "${pkgs.openssl.dev}/lib/pkgconfig";
        };
      }
    );
}
